@@ -2,17 +2,18 @@ package Text::Template::Simple::Cache;
 use strict;
 use vars qw($VERSION);
 use constant CACHE_PARENT => 0;
-use Text::Template::Simple::Constants qw(:all);
-use Text::Template::Simple::Util qw( DEBUG LOG ishref fatal );
+use Text::Template::Simple::Constants;
+use Text::Template::Simple::Util qw( DEBUG LOG ishref );
+use Text::Template::Simple::Cache::ID;
 use Carp qw( croak );
 
-$VERSION = '0.79_09';
+$VERSION = '0.52';
 
 my $CACHE = {}; # in-memory template cache
 
 sub new {
    my $class  = shift;
-   my $parent = shift || fatal('tts.cache.new.parent');
+   my $parent = shift || croak "Parent object is missing";
    my $self   = [undef];
    bless $self, $class;
    $self->[CACHE_PARENT] = $parent;
@@ -42,14 +43,14 @@ sub reset {
 
       my $cdir = $parent->[CACHE_DIR];
       local  *CDIRH;
-      opendir CDIRH, $cdir or fatal( 'tts.cache.opendir' => $cdir, $! );
+      opendir CDIRH, $cdir or croak fatal( CDIROPEN => $cdir, $! );
       require File::Spec;
       my $ext = quotemeta CACHE_EXT;
       my $file;
 
       while ( defined( $file = readdir CDIRH ) ) {
-         next if $file !~ m{ ( .* $ext) \z}xmsi;
-         $file = File::Spec->catfile( $parent->[CACHE_DIR], $1 );
+         next if $file !~ m{ $ext \z}xmsi;
+         $file = File::Spec->catfile( $parent->[CACHE_DIR], $file );
          LOG( UNLINK => $file ) if DEBUG();
          unlink $file;
       }
@@ -62,9 +63,9 @@ sub dumper {
    my $self  = shift;
    my $type  = shift || 'structure';
    my $param = shift || {};
-   fatal('tts.cache.dumper.hash')        if not ishref $param;
+   croak "Parameters to dumper() must be a HASHref" if not ishref $param;
    my %valid = map { $_, $_ } qw( ids structure );
-   fatal('tts.cache.dumper.type', $type) if not $valid{ $type };
+   croak "dumper type '$type' is not valid " if not $valid{ $type };
    my $method = '_dump_' . $type;
    return $self->$method( $param ); # TODO: modify the methods to accept HASH
 }
@@ -119,7 +120,7 @@ sub _dump_structure {
    else {
       $d = Data::Dumper->new( [ $CACHE ], [ $VAR ]);
       if ( $deparse ) {
-         fatal('tts.cache.dumper' => $Data::Dumper::VERSION) if !$d->can('Deparse');
+         croak fatal(DUMPER => $Data::Dumper::VERSION) if !$d->can('Deparse');
          $d->Deparse(1);
       }
    }
@@ -201,16 +202,14 @@ sub size {
       return $total;
 
    }
-   else { # in-memory cache
+   else { # in memory cache
 
       local $SIG{__DIE__};
       if ( eval { require Devel::Size; 1; } ) {
-         my $dsv = Devel::Size->VERSION;
-         LOG( DEBUG => "Devel::Size v$dsv is loaded." )
+         LOG( DEBUG => "Devel::Size v$Devel::Size::VERSION is loaded." )
             if DEBUG();
-         fatal('tts.cache.develsize.buggy', $dsv) if $dsv < 0.72;
          my $size = eval { Devel::Size::total_size( $CACHE ) };
-         fatal('tts.cache.develsize.total', $@) if $@;
+         die "Devel::Size::total_size(): $@" if $@;
          return $size;
       }
       else {
@@ -230,13 +229,13 @@ sub has {
       return;
    }
 
-   fatal('tts.cache.pformat') if @_ % 2;
+   croak fatal('PFORMAT') if @_ % 2;
 
    my %opt = @_;
-   my $id  = $parent->connector('Cache::ID')->new;
+   my $id  = Text::Template::Simple::Cache::ID->new;
    my $cid = $opt{id}   ? $id->generate($opt{id}  , 'custom')
            : $opt{data} ? $id->generate($opt{data}          )
-           :              fatal('tts.cache.incache');
+           :              croak fatal('INCACHE');
 
    if ( my $cdir = $parent->[CACHE_DIR] ) {
       require File::Spec;
@@ -247,21 +246,7 @@ sub has {
    }
 }
 
-sub _is_meta_version_old {
-   my $self = shift;
-   my $v    = shift;
-   return 1 if ! $v; # no version? archaic then
-   my $pv = PARENT->VERSION;
-   foreach my $i ( $v, $pv ) {
-      $i  =~ tr/_//d; # underscore versions cause warnings
-      $i +=  0;       # force number
-   }
-   return 1 if $v < $pv;
-   return;
-}
-
 sub hit {
-   # TODO: return $CODE, $META;
    my $self     = shift;
    my $parent   = $self->[CACHE_PARENT];
    my $cache_id = shift;
@@ -274,30 +259,20 @@ sub hit {
 
       if ( -e $cache && not -d _ && -f _ ) {
          my $disk_cache = $parent->io->slurp($cache);
-         my %meta;
-         if ( $disk_cache =~ m{ \A \#META: (.+?) \n }xms ) {
-            %meta = $self->_get_meta( $1 );
-            fatal('tts.cache.hit.meta', $@) if $@;
-         }
-         if ( $self->_is_meta_version_old( $meta{VERSION} ) ) {
-            my $id = $parent->[FILENAME] || $cache_id;
-            warn "(This messeage will only appear once) $id was compiled with"
-                ." an old version of " . PARENT . ". Resetting cache.";
-            return;
-         }
-         if ( my $mtime = $meta{CHKMT} ) {
-            if ( $mtime != $chkmt ) {
-               LOG( MTIME_DIFF => "\tOLD: $mtime\n\t\tNEW: $chkmt")
-                  if DEBUG();
-               return; # i.e.: Update cache
+
+         if ( $chkmt ) {
+            if ( $disk_cache =~ m{^#(\d+)#} ) {
+               my $mtime  = $1;
+               if ( $mtime != $chkmt ) {
+                  LOG( MTIME_DIFF => "\tOLD: $mtime\n\t\tNEW: $chkmt")
+                     if DEBUG();
+                  return; # i.e.: Update cache
+               }
             }
          }
 
          ($CODE, $error) = $parent->_wrap_compile($disk_cache);
-         $parent->[NEEDS_OBJECT] = $meta{NEEDS_OBJECT} if $meta{NEEDS_OBJECT};
-         $parent->[FAKER_SELF]   = $meta{FAKER_SELF}   if $meta{FAKER_SELF};
-
-         fatal('tts.cache.hit.cache', $error) if $error;
+         croak "Error loading from disk cache: $error" if $error;
          LOG( FILE_CACHE => '' ) if DEBUG();
          #$parent->[COUNTER]++;
          return $CODE;
@@ -334,40 +309,26 @@ sub populate {
          require Fcntl;
          require IO::File;
 
-         my %meta = (
-            CHKMT        => $chkmt,
-            NEEDS_OBJECT => $parent->[NEEDS_OBJECT],
-            FAKER_SELF   => $parent->[FAKER_SELF],
-            VERSION      => PARENT->VERSION,
-         );
-
          my $cache = File::Spec->catfile( $cdir, $cache_id . CACHE_EXT);
          my $fh    = IO::File->new;
-         $fh->open($cache, '>') or fatal('tts.cache.populate.write', $cache, $!);
+         $fh->open($cache, '>') or croak "Error writing disk-cache $cache : $!";
          flock $fh, Fcntl::LOCK_EX() if IS_FLOCK;
          $parent->io->layer($fh);
-         my $warn =  $parent->_mini_compiler(
-                        $parent->_internal('disk_cache_comment'),
-                        {
-                           NAME => PARENT->_class_id,
-                           DATE => scalar localtime time,
-                        }
-                     );
-         print $fh '#META:' . $self->_set_meta(\%meta) . "\n", $warn, $parsed; 
+         print $fh $chkmt ? "#$chkmt#\n" : "##\n",
+                   sprintf( DISK_CACHE_COMMENT,
+                            PARENT->_parser_id, scalar localtime time),
+                   $parsed; 
          flock $fh, Fcntl::LOCK_UN() if IS_FLOCK;
          close $fh;
-         chmod(CACHE_FMODE, $cache) || fatal('tts.cache.populate.chmod');
 
          ($CODE, $error) = $parent->_wrap_compile($parsed);
          LOG( DISK_POPUL => $cache_id ) if DEBUG() > 2;
       } 
       else {
-         $CACHE->{ $cache_id } = {}; # init
-         ($CODE, $error)                       = $parent->_wrap_compile($parsed);
-         $CACHE->{ $cache_id }->{CODE}         = $CODE;
-         $CACHE->{ $cache_id }->{MTIME}        = $chkmt if $chkmt;
-         $CACHE->{ $cache_id }->{NEEDS_OBJECT} = $parent->[NEEDS_OBJECT];
-         $CACHE->{ $cache_id }->{FAKER_SELF}   = $parent->[FAKER_SELF];
+         $CACHE->{$cache_id} = {CODE => undef, MTIME => 0}; # init
+         ($CODE, $error) = $parent->_wrap_compile($parsed);
+         $CACHE->{$cache_id}->{CODE}  = $CODE;
+         $CACHE->{$cache_id}->{MTIME} = $chkmt if $chkmt;
          LOG( MEM_POPUL => $cache_id ) if DEBUG() > 2;
       }
    }
@@ -379,39 +340,16 @@ sub populate {
    if ( $error ) {
       my $cid    = $cache_id ? $cache_id : 'N/A';
       my $tidied = $parent->_tidy( $parsed );
-      croak $parent->[VERBOSE_ERRORS]
-            ? $parent->_mini_compiler( $parent->_internal('compile_error'), {
-               CID => $cid,
-               ERROR => $error,
-               PARSED => $parsed,
-               TIDIED => $tidied,
-                                                                        } )
-            : $error
-            ;
+      croak sprintf COMPILE_ERROR_TMP, $cid, $error, $parsed, $tidied;
    }
 
    $parent->[COUNTER]++;
    return $CODE;
 }
 
-sub _get_meta {
-   my $self = shift;
-   my $raw  = shift;
-   my %meta = map { split /:/, $_ } split /\|/, $raw;
-   return %meta;
-}
-
-sub _set_meta {
-   my $self = shift;
-   my $meta = shift;
-   my $rv   = join '|', map { $_ . ':' . $meta->{ $_ } } keys %{ $meta };
-   return $rv;
-}
-
 sub DESTROY {
    my $self = shift;
-   LOG( DESTROY => ref $self ) if DEBUG();
-   $self->[CACHE_PARENT] = undef;
+   LOG( DESTROY => ref $self ) if DEBUG;
    @{$self} = ();
    return;
 }
@@ -430,13 +368,6 @@ TODO
 
 =head1 DESCRIPTION
 
-This document describes version C<0.79_09> of C<Text::Template::Simple::Cache>
-released on C<7 August 2009>.
-
-B<WARNING>: This version of the module is part of a
-developer (beta) release of the distribution and it is
-not suitable for production use.
-
 Cache manager for C<Text::Template::Simple>.
 
 =head1 METHODS
@@ -531,16 +462,16 @@ TODO
 
 =head1 AUTHOR
 
-Burak Gursoy <burak@cpan.org>.
+Burak GE<252>rsoy, E<lt>burakE<64>cpan.orgE<gt>
 
 =head1 COPYRIGHT
 
-Copyright 2004 - 2009 Burak Gursoy. All rights reserved.
+Copyright 2008 Burak GE<252>rsoy. All rights reserved.
 
 =head1 LICENSE
 
 This library is free software; you can redistribute it and/or modify 
-it under the same terms as Perl itself, either Perl version 5.10.0 or, 
+it under the same terms as Perl itself, either Perl version 5.8.8 or, 
 at your option, any later version of Perl 5 you may have available.
 
 =cut
