@@ -2,7 +2,35 @@ package Text::Template::Simple::Constants;
 use strict;
 use vars qw($VERSION $OID @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS);
 
-$VERSION = '0.50';
+$VERSION = '0.52';
+
+# object fields
+BEGIN { $OID = -1 } # init object field id counter
+use constant DELIMITERS     => ++$OID;
+use constant AS_STRING      => ++$OID;
+use constant DELETE_WS      => ++$OID;
+use constant FAKER          => ++$OID;
+use constant FAKER_HASH     => ++$OID;
+use constant CACHE          => ++$OID;
+use constant CACHE_DIR      => ++$OID;
+use constant CACHE_OBJECT   => ++$OID;
+use constant IO_OBJECT      => ++$OID;
+use constant STRICT         => ++$OID;
+use constant SAFE           => ++$OID;
+use constant HEADER         => ++$OID;
+use constant ADD_ARGS       => ++$OID;
+use constant WARN_IDS       => ++$OID;
+use constant FIX_UNCUDDLED  => ++$OID;
+use constant TYPE           => ++$OID;
+use constant COUNTER        => ++$OID;
+use constant CID            => ++$OID;
+use constant FILENAME       => ++$OID;
+use constant RESUME         => ++$OID;
+use constant IOLAYER        => ++$OID;
+use constant STACK          => ++$OID;
+use constant USER_THANDLER  => ++$OID;
+# number of the last object field
+use constant MAXOBJFIELD    =>   $OID;
 
 use constant PARENT         => 'Text::Template::Simple';
 use constant IS_WINDOWS     => $^O eq 'MSWin32' || $^O eq 'MSWin64';
@@ -92,16 +120,14 @@ TEMPLATE_CONSTANT
 
 use constant DISK_CACHE_COMMENT => <<"TEMPLATE_CONSTANT";
 # !!!   W A R N I N G      W A R N I N G      W A R N I N G   !!!
-# This file is automatically generated by %s v%s on %s.
+# This file is automatically generated by %s on %s.
 # This file is a compiled template cache.
 # Any changes you make here will be lost.
 #
-#
-#
-#
-# [line 10]
 TEMPLATE_CONSTANT
 
+use constant DISK_CACHE_MARKER => q{# This file is automatically generated by } . PARENT;
+
 use constant RESUME_TEMPLATE => sub {
    my $tmp = q~
          .= sub {
@@ -151,31 +177,6 @@ use constant RESUME_ELSE => qr{
 
 use constant RESUME_LOOP => qr{ (?:next|last|continue|redo) }xms;
 
-# object fields
-BEGIN { $OID = -1 } # init object field id counter
-use constant DELIMITERS     => ++$OID;
-use constant AS_STRING      => ++$OID;
-use constant DELETE_WS      => ++$OID;
-use constant FAKER          => ++$OID;
-use constant FAKER_HASH     => ++$OID;
-use constant CACHE          => ++$OID;
-use constant CACHE_DIR      => ++$OID;
-use constant STRICT         => ++$OID;
-use constant SAFE           => ++$OID;
-use constant HEADER         => ++$OID;
-use constant ADD_ARGS       => ++$OID;
-use constant WARN_IDS       => ++$OID;
-use constant FIX_UNCUDDLED  => ++$OID;
-use constant TYPE           => ++$OID;
-use constant COUNTER        => ++$OID;
-use constant CID            => ++$OID;
-use constant FILENAME       => ++$OID;
-use constant RESUME         => ++$OID;
-use constant IOLAYER        => ++$OID;
-use constant STACK          => ++$OID;
-# number of the last object field
-use constant MAXOBJFIELD    =>   $OID;
-
 use Exporter ();
 
 BEGIN {
@@ -198,6 +199,7 @@ BEGIN {
                         COMPILE_ERROR_TMP
                         FRAGMENT_TMP
                         DISK_CACHE_COMMENT
+                        DISK_CACHE_MARKER
                         MAP_KEYS_CHECK
                         MAP_KEYS_INIT
                         MAP_KEYS_DEFAULT
@@ -215,6 +217,8 @@ BEGIN {
                         FAKER_HASH
                         CACHE
                         CACHE_DIR
+                        CACHE_OBJECT
+                        IO_OBJECT
                         STRICT
                         SAFE
                         HEADER
@@ -228,6 +232,7 @@ BEGIN {
                         RESUME
                         IOLAYER
                         STACK
+                        USER_THANDLER
                         MAXOBJFIELD
                      )],
       resume    =>   [qw(
@@ -260,7 +265,7 @@ __END__
 
 =head1 NAME
 
-Text::Template::Simple::Constants - Constants for Text::Template::Simple
+Text::Template::Simple::Constants - Constants
 
 =head1 SYNOPSIS
 
