@@ -18,7 +18,7 @@ use constant SUBSTR_LENGTH =>  1;
 
 use Carp qw( croak );
 
-$VERSION = '0.50';
+$VERSION = '0.52';
 
 my @COMMANDS = (
    #   cmd id        callback
@@ -87,7 +87,7 @@ sub _token_code {
    my $fu       = $self->[ID_FU];
 
    my($cmd, $len, $cb, $buf);
-   TCODE: foreach $cmd ( @COMMANDS ) {
+   TCODE: foreach $cmd ( @COMMANDS, $self->_user_commands ) {
       if ( $first eq $cmd->[CMD_CHAR] ) {
          $len = length($str);
          $cb  = $cmd->[CMD_CB];
@@ -112,6 +112,12 @@ sub _token_code {
    return [ RAW => $self->tilde( $str ) ];
 }
 
+sub _user_commands {
+   my $self = shift;
+   return +() if ! $self->can('commands');
+   return $self->commands;
+}
+
 sub tilde {
    my $self = shift;
    my $s    = shift;
@@ -140,7 +146,7 @@ __END__
 
 =head1 NAME
 
-Text::Template::Simple::Tokenizer - Tokenizer for Text::Template::Simple
+Text::Template::Simple::Tokenizer - Tokenizer
 
 =head1 SYNOPSIS
 
